==> share-1.0.58.tgz: package/README.md <==
# @zubyjs/share

The plugin for Zuby.js that allows you to share your local development/prod
server with anyone in the world using the Cloudflare [Quick Tunnel](https://developers.cloudflare.com/cloudflare-one/connections/connect-networks/do-more-with-tunnels/trycloudflare/) service.
This is useful when you want to show your work to someone else,
or quickly test it on a different device.

By using this plugin,
you agree to the Cloudflare's [Terms of Service](https://www.cloudflare.com/terms/),
[Privacy Policy](https://www.cloudflare.com/privacypolicy/),
and [Tunnel License](https://developers.cloudflare.com/cloudflare-one/connections/connect-networks/downloads/license/).

## Installation

First, install the `@zubyjs/share` package using your favorite package manager.
If you aren't sure, you can use npm:

```sh
npm install @zubyjs/share
```

Then add the `@zubyjs/share` plugin to your `zuby.config.mjs` file under the `plugins` option:

```diff lang="js" title="zuby.config.mjs"
  import { defineConfig } from 'zuby';
  import preact from '@zubyjs/preact';
+ import share from '@zubyjs/share';

  export default defineConfig({
    outDir: '.zuby',
    jsx: preact(),
+   plugins: [
+       share()
+   ]
    ^^^^^^^^
  });
```

And that's it!
Now you can run `npx zuby dev` or `npx zuby preview` to start sharing your local server.
The plugin will expose your local dev/prod server to the internet over a tunnel
and provide you a unique link that you can share with anyone.
Once you stop the server, the tunnel will be closed.

Example output:

```diff lang="json"
Zuby.js  v1.0.58  started in 379ms

┃ Mode     development
┃ Local    http://127.0.0.1:3000/
┃ Network  use --host and --port to expose

┃ Share  https://accidents-head-random.trycloudflare.com
```

NOTE: Always make sure that all zuby packages are in sync in your `package.json` file:

```diff lang="json"
  {
    "name": "my-zuby-app",
    "version": "1.0.0",
    "dependencies": {
      "zuby": "latest",
      "@zubyjs/share": "latest"
    }
  }
```

## Contributing

This package is part of Zuby.js workspace and maintained by the team behind the [Zuby package](https://www.npmjs.com/package/zuby).
Please refer to it for more details how to contribute.

## License

MIT

==> share-1.0.59.tgz: package/README.md <==
# @zubyjs/share

The plugin for Zuby.js that allows you to easily share your local development/prod
server with anyone in the world using the Cloudflare [Quick Tunnel](https://developers.cloudflare.com/cloudflare-one/connections/connect-networks/do-more-with-tunnels/trycloudflare/) service.
This is useful when you want to show your work to someone else,
or quickly test it on a different device.

By using this plugin,
you agree to the Cloudflare's [Terms of Service](https://www.cloudflare.com/terms/),
[Privacy Policy](https://www.cloudflare.com/privacypolicy/),
and [Tunnel License](https://developers.cloudflare.com/cloudflare-one/connections/connect-networks/downloads/license/).

## Installation

First, install the `@zubyjs/share` package using your favorite package manager.
If you aren't sure, you can use npm:

```sh
npm install @zubyjs/share
```

Then add the `@zubyjs/share` plugin to your `zuby.config.mjs` file under the `plugins` option:

```diff lang="js" title="zuby.config.mjs"
  import { defineConfig } from 'zuby';
  import preact from '@zubyjs/preact';
+ import share from '@zubyjs/share';

  export default defineConfig({
    outDir: '.zuby',
    jsx: preact(),
+   plugins: [
+       share()
+   ]
    ^^^^^^^^
  });
```

And that's it!
Now you can run `npx zuby dev` or `npx zuby preview` to start sharing your local server.
The plugin will expose your local dev/prod server to the internet over a tunnel
and provide you a unique link that you can share with anyone.
Once you stop the server, the tunnel is closed.

Example output:

```lang="sh"
Zuby.js  v1.0.58  started in 379ms

┃ Mode     development
┃ Local    http://127.0.0.1:3000/
┃ Network  use --host and --port to expose

┃ Share  https://accidents-head-random.trycloudflare.com
```

NOTE: Always make sure that all zuby packages are in sync in your `package.json` file:

```diff lang="json"
  {
    "name": "my-zuby-app",
    "version": "1.0.0",
    "dependencies": {
      "zuby": "latest",
      "@zubyjs/share": "latest"
    }
  }
```

## Contributing

This package is part of Zuby.js workspace and maintained by the team behind the [Zuby package](https://www.npmjs.com/package/zuby).
Please refer to it for more details how to contribute.

## License

MIT
